# About the Authors

## [Joshua Charles Campbell](http://webdocs.cs.ualberta.ca/~joshua2/)

Ph.D. Student, Research Assistant and Teaching Assistant

Department of Computing Science

University of Alberta

joshua2@ualberta.ca

## [Abram Hindle](http://softwareprocess.es/static/SoftwareProcess.es.html)

Assistant Professor

Department of Computing Science

University of Alberta

hindle1@ualberta.ca

## Other Contributors

Eddie Antonio Santos

Alex Wilson

Graham Forest

Earl T. Barr

Prem Devanbu

Daryl Posnett
